@@ -88,7 +88,7 @@ if args.model_name is not None and not args.model_path:
 if args.vocoder_name is not None and not args.vocoder_path:
     vocoder_path, vocoder_config_path, _ = manager.download_model(args.vocoder_name)
 
-# CASE3: set custome model paths
+# CASE3: set custom model paths
 if args.model_path is not None:
     model_path = args.model_path
     config_path = args.config_path
@@ -170,9 +170,9 @@ def tts():
     text = request.args.get("text")
     speaker_idx = request.args.get("speaker_id", "")
     style_wav = request.args.get("style_wav", "")
-
     style_wav = style_wav_uri_to_dict(style_wav)
     print(" > Model input: {}".format(text))
+    print(" > Speaker Idx: {}".format(speaker_idx))
     wavs = synthesizer.tts(text, speaker_name=speaker_idx, style_wav=style_wav)
     out = io.BytesIO()
     synthesizer.save_wav(wavs, out)
