@@ -142,10 +142,10 @@ class TorchSTFT(nn.Module):  # pylint: disable=abstract-method
         )
         M = o[:, :, :, 0]
         P = o[:, :, :, 1]
-        S = torch.sqrt(torch.clamp(M ** 2 + P ** 2, min=1e-8))
+        S = torch.sqrt(torch.clamp(M**2 + P**2, min=1e-8))
 
         if self.power is not None:
-            S = S ** self.power
+            S = S**self.power
 
         if self.use_mel:
             S = torch.matmul(self.mel_basis.to(x), S)
@@ -239,6 +239,12 @@ class AudioProcessor(object):
         mel_fmax (int, optional):
             maximum filter frequency for computing melspectrograms. Defaults to None.
 
+        pitch_fmin (int, optional):
+            minimum filter frequency for computing pitch. Defaults to None.
+
+        pitch_fmax (int, optional):
+            maximum filter frequency for computing pitch. Defaults to None.
+
         spec_gain (int, optional):
             gain applied when converting amplitude to DB. Defaults to 20.
 
@@ -300,6 +306,8 @@ class AudioProcessor(object):
         max_norm=None,
         mel_fmin=None,
         mel_fmax=None,
+        pitch_fmax=None,
+        pitch_fmin=None,
         spec_gain=20,
         stft_pad_mode="reflect",
         clip_norm=True,
@@ -333,6 +341,8 @@ class AudioProcessor(object):
         self.symmetric_norm = symmetric_norm
         self.mel_fmin = mel_fmin or 0
         self.mel_fmax = mel_fmax
+        self.pitch_fmin = pitch_fmin
+        self.pitch_fmax = pitch_fmax
         self.spec_gain = float(spec_gain)
         self.stft_pad_mode = stft_pad_mode
         self.max_norm = 1.0 if max_norm is None else float(max_norm)
@@ -379,6 +389,12 @@ class AudioProcessor(object):
             self.clip_norm = None
             self.symmetric_norm = None
 
+    @staticmethod
+    def init_from_config(config: "Coqpit", verbose=True):
+        if "audio" in config:
+            return AudioProcessor(verbose=verbose, **config.audio)
+        return AudioProcessor(verbose=verbose, **config)
+
     ### setting up the parameters ###
     def _build_mel_basis(
         self,
@@ -634,8 +650,8 @@ class AudioProcessor(object):
         S = self._db_to_amp(S)
         # Reconstruct phase
         if self.preemphasis != 0:
-            return self.apply_inv_preemphasis(self._griffin_lim(S ** self.power))
-        return self._griffin_lim(S ** self.power)
+            return self.apply_inv_preemphasis(self._griffin_lim(S**self.power))
+        return self._griffin_lim(S**self.power)
 
     def inv_melspectrogram(self, mel_spectrogram: np.ndarray) -> np.ndarray:
         """Convert a melspectrogram to a waveform using Griffi-Lim vocoder."""
@@ -643,8 +659,8 @@ class AudioProcessor(object):
         S = self._db_to_amp(D)
         S = self._mel_to_linear(S)  # Convert back to linear
         if self.preemphasis != 0:
-            return self.apply_inv_preemphasis(self._griffin_lim(S ** self.power))
-        return self._griffin_lim(S ** self.power)
+            return self.apply_inv_preemphasis(self._griffin_lim(S**self.power))
+        return self._griffin_lim(S**self.power)
 
     def out_linear_to_mel(self, linear_spec: np.ndarray) -> np.ndarray:
         """Convert a full scale linear spectrogram output of a network to a melspectrogram.
@@ -720,11 +736,12 @@ class AudioProcessor(object):
             >>> WAV_FILE = filename = librosa.util.example_audio_file()
             >>> from TTS.config import BaseAudioConfig
             >>> from TTS.utils.audio import AudioProcessor
-            >>> conf = BaseAudioConfig(mel_fmax=8000)
+            >>> conf = BaseAudioConfig(pitch_fmax=8000)
             >>> ap = AudioProcessor(**conf)
             >>> wav = ap.load_wav(WAV_FILE, sr=22050)[:5 * 22050]
             >>> pitch = ap.compute_f0(wav)
         """
+        assert self.pitch_fmax is not None, " [!] Set `pitch_fmax` before caling `compute_f0`."
         # align F0 length to the spectrogram length
         if len(x) % self.hop_length == 0:
             x = np.pad(x, (0, self.hop_length // 2), mode="reflect")
@@ -732,7 +749,7 @@ class AudioProcessor(object):
         f0, t = pw.dio(
             x.astype(np.double),
             fs=self.sample_rate,
-            f0_ceil=self.mel_fmax,
+            f0_ceil=self.pitch_fmax,
             frame_period=1000 * self.hop_length / self.sample_rate,
         )
         f0 = pw.stonemask(x.astype(np.double), f0, t, self.sample_rate)
@@ -781,7 +798,7 @@ class AudioProcessor(object):
     @staticmethod
     def _rms_norm(wav, db_level=-27):
         r = 10 ** (db_level / 20)
-        a = np.sqrt((len(wav) * (r ** 2)) / np.sum(wav ** 2))
+        a = np.sqrt((len(wav) * (r**2)) / np.sum(wav**2))
         return wav * a
 
     def rms_volume_norm(self, x: np.ndarray, db_level: float = None) -> np.ndarray:
@@ -853,7 +870,7 @@ class AudioProcessor(object):
 
     @staticmethod
     def mulaw_encode(wav: np.ndarray, qc: int) -> np.ndarray:
-        mu = 2 ** qc - 1
+        mu = 2**qc - 1
         # wav_abs = np.minimum(np.abs(wav), 1.0)
         signal = np.sign(wav) * np.log(1 + mu * np.abs(wav)) / np.log(1.0 + mu)
         # Quantize signal to the specified number of levels.
@@ -865,13 +882,13 @@ class AudioProcessor(object):
     @staticmethod
     def mulaw_decode(wav, qc):
         """Recovers waveform from quantized values."""
-        mu = 2 ** qc - 1
+        mu = 2**qc - 1
         x = np.sign(wav) / mu * ((1 + mu) ** np.abs(wav) - 1)
         return x
 
     @staticmethod
     def encode_16bits(x):
-        return np.clip(x * 2 ** 15, -(2 ** 15), 2 ** 15 - 1).astype(np.int16)
+        return np.clip(x * 2**15, -(2**15), 2**15 - 1).astype(np.int16)
 
     @staticmethod
     def quantize(x: np.ndarray, bits: int) -> np.ndarray:
@@ -884,12 +901,12 @@ class AudioProcessor(object):
         Returns:
             np.ndarray: Quantized waveform.
         """
-        return (x + 1.0) * (2 ** bits - 1) / 2
+        return (x + 1.0) * (2**bits - 1) / 2
 
     @staticmethod
     def dequantize(x, bits):
         """Dequantize a waveform from the given number of bits."""
-        return 2 * x / (2 ** bits - 1) - 1
+        return 2 * x / (2**bits - 1) - 1
 
 
 def _log(x, base):
